* Runs mortality for each background characteristic.

*Male.
Define subgroup ()
  '(Male TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

*total children ever born.
compute ceb = 0.
if (CM3 = 1) ceb = ceb + CM4A.
if (CM5 = 1) ceb = ceb + CM6A.
if (CM7 = 1) ceb = ceb + CM8A.

*number of dead children.
do if (CM7 = 1).
+ compute deadkids = CM8A.
else.
+ compute deadkids = 0.
end if.

weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 1.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute sex = 1.

aggregate outfile = 'tmpresult.sav'
  /break sex
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).



*----------------------------------------------------------------.
*Female.
Define subgroup ()
  '(Female TSFB)'
!enddefine.

get file='WM.sav'.
select if (WM7 = 1).

*total children ever born.
compute ceb = 0.
if (CM3 = 1) ceb = ceb + CM4B.
if (CM5 = 1) ceb = ceb + CM6B.
if (CM7 = 1) ceb = ceb + CM8B.

*number of dead children.
do if (CM7 = 1).
+ compute deadkids = CM8B.
else.
+ compute deadkids = 0.
end if.

weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 2.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute sex = 2.

aggregate outfile = 'tmp.sav'
  /break sex
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Urban.
Define subgroup ()
  '(Urban TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (HH6 = 1).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute hh6 = 1.

aggregate outfile = 'tmp.sav'
  /break hh6
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Rural.
Define subgroup ()
  '(Rural TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (HH6 = 2).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute hh6 = 2.

aggregate outfile = 'tmp.sav'
  /break hh6
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Mother's education .
Define subgroup ()
  '(None/Primary TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (melevel = 1 or melevel = 2).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute melevel = 2.

aggregate outfile = 'tmp.sav'
  /break melevel
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Mother's education.
Define subgroup ()
  '(Secondary + TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (melevel = 3 or melevel = 4).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute melevel = 3.

aggregate outfile = 'tmp.sav'
  /break melevel
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Wealth index quintiles.
Define subgroup ()
  '(Poorest TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (wlthind5 = 1 or wlthind5 = 2 or wlthind5 = 3).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute wlthind = 1.

aggregate outfile = 'tmp.sav'
  /break wlthind
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Wealth index quintiles.
Define subgroup ()
  '(Richest TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (wlthind5 = 4 or wlthind5 = 5).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute wlthind = 2.

aggregate outfile = 'tmp.sav'
  /break wlthind
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Ethnicity.
Define subgroup ()
  '(Macedonian TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (HC1B = 1).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute egroup = 1.

aggregate outfile = 'tmp.sav'
  /break egroup
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.
*Ethnicity.
Define subgroup ()
  '(Albanian TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (HC1B = 3).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute egroup = 2.

aggregate outfile = 'tmp.sav'
  /break egroup
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.


*----------------------------------------------------------------.
*Ethnicity group.
Define subgroup ()
  '(Roma TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

compute filter_$ =  (HC1B = 5).
filter by filter_$.
weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute egroup = 3.

aggregate outfile = 'tmp.sav'
  /break egroup
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.
save outfile='tmpresult.sav'.



*----------------------------------------------------------------.

*Total.
Define subgroup ()
  '(Total TSFB)'
!enddefine.

get file='WM.sav'.

select if (WM7 = 1).

weight by wmweight.

* Set sex  1 = male, 2 = female, 3 = total.
compute qfivesex = 3.

* Execute the bulk of the qfive process.
include file = 'qfive TSFB setup.sps'.

* Calculate mean of 0-4 group from the east model.
select if (tsfb = 1).
compute total = 1.

aggregate outfile = 'tmp.sav'
  /break total
  /imr = mean(imrea)
  /u5mr = mean(u5mrea).

get file 'tmpresult.sav'.
add files
  /file = *
  /file = 'tmp.sav'.



*----------------------------------------------------------------.

variable label imr 'Infant Mortality Rate*'.
variable label u5mr 'Under-five Mortality Rate**'.
variable label sex 'Sex'.
variable label hh6 'Area'.
variable label wlthind 'Wealth index quintiles'.
variable label egroup 'Ethnicicty'.
variable label melevel "Mother's education".
variable label total 'Total'.

value label sex 1 'Male' 2 'Female'.
value label hh6 1 'Urban' 2 'Rural'.
value label wlthind 1 'Poorest 60%' 2 'Richest 40%'.
value label egroup 1 'Macedonian' 2 'Albanian' 3 'Roma'.
value label melevel 2 'None/Primary' 3 'Secondary+'.
value label total 1 'Total'.

Compute imrm = imr*1000.
Compute u5mrm = u5mr*1000.
variable label imrm 'Infant Mortality Rate*'.
variable label u5mrm "Under-five Mortality Rate**".

* Comment - table below commented out and replaced by custom table
table
  /observation = imrm u5mrm
  /table= sex +hh6+melevel+wlthind+egroup+total  by imrm + u5mrm
  /statistics
    mean( imrm (F7.0) '')
    mean( u5mrm (F7.0) '')
  /title
   "Table CM.1: Child mortality" 
             "Infant and under-five mortality rates [based on east model], Republic of Macedonia, 2005"
/caption
       "* MICS indicator 2; MDG indicator 14" 
       "** MICS indicator 1; MDG indicator13".

CTABLES
  /MRSETS COUNTDUPLICATES=YES
  /FORMAT EMPTY=BLANK
  /TABLE sex[C]+hh6[C]+melevel[C]+wlthind[C]+egroup[C]+total[C] BY 
         imrm[S][MEAN,'',F7.0]+u5mrm[S][MEAN,'',F7.0]
  /CATEGORIES VAR=ALL EMPTY=EXCLUDE MISSING=EXCLUDE
  /SLABELS POSITION=COLUMN
  /TITLE TITLE="Table CM.1: Child mortality"
         "Infant and under-five mortality rates [based on east model], Republic of Macedonia, 2005"
  CAPTION="* MICS indicator 2; MDG indicator 14"
          "** MICS indicator 1; MDG indicator13".

new file.
erase file='tmp.sav'.
erase file='tmp2.sav'.
erase file='tmpcmr.sav'.
erase file='tmpresult.sav'.
